@@ -3,11 +3,12 @@
 # TODO 
 # compute score by sum of error div. by number of hits
 
-findNN<-function(q, vec) {
+findNN<-function(q, vec, check=FALSE) {
 
-    if (is.unsorted(vec)){
+    if (check){ if ( is.unsorted(vec)){
         return (list(error="vec is not sorted"))
-    }
+    }}
+
 
     out <- .C("findNN",
         m=as.integer(length(q)),
@@ -17,5 +18,5 @@ findNN<-function(q, vec) {
         NN=as.integer(rep(-1, length(q))),
         PACKAGE = "protViz")
 
-    return (out$NN+1)
+    return (out$NN + 1)
 }
